pub(crate) enum DepthSegment {
Regular(Span),
Opaque(BucketRange),
}Variants
Regular(Span)
An opaque span that cannot be tracked in the depth buffer because it is not aligned to whole depth buckets.
Opaque(BucketRange)
An opaque span that is aligned and can therefore be rendered front-to-back with depth-buffer write enabled.