DepthBuffer

Struct DepthBuffer 

pub(crate) struct DepthBuffer {
    data: Vec<u32>,
}

Fields

data: Vec<u32>

Stores the maximum draw ID for each depth bucket.

Implementations

Source

impl DepthBuffer

pub(crate) fn new(buffer_width: u16) -> Self

pub(crate) fn for_each_unset_run(&self, span: Span, f: impl FnMut(Span))

Calls f for every subspan of span that is not covered by any entry in the depth buffer.

pub(crate) fn for_each_unset_run_and_write( &mut self, bucket_range: BucketRange, draw_id: u32, f: impl FnMut(BucketRange), )

Calls f for every bucket run in bucket_range that is not covered by any entry in the depth buffer, and then marks the newly covered buckets in the depth buffer.

pub(crate) fn for_each_visible_run( &self, span: Span, draw_id: u32, f: impl FnMut(Span), )

Calls f for every subspan of span that should be considered as visible assuming the given draw ID.

fn range(&self, span: Span) -> (usize, usize)

Returns the depth-bucket index range touched by span.

pub(crate) fn clear(&mut self)

fn mark(&mut self, range: Range<usize>, draw_id: u32)

fn next_unset_run( &self, idx: &mut usize, end: usize, bounds: Span, ) -> Option<(Span, Range<usize>)>

Finds the next consecutive run of unset depth buckets.

fn next_visible_run( &self, idx: &mut usize, end: usize, draw_id: u32, bounds: Span, ) -> Option<Span>

Finds the next consecutive run visible to draw_id.